DataLad Catalog
***************

.. image:: https://readthedocs.org/projects/datalad-catalog/badge/?version=latest
   :target: http://docs.datalad.org/projects/catalog/en/latest/?badge=latest
   :alt: Documentation Status

Welcome to the user and technical documentation of DataLad Catalog,
a DataLad extension that allows you to create a user-friendly data
browser from structured DataLad-generated metadata.

.. image:: /_static/datalad_catalog_logo_1_dark.svg
   :height: 100px
   :width: 200 px
   :alt: alternate text
   :align: center

|




Demo
====

See our `demo catalog`_, hosted via GitHub Pages. This catalog was generated
from the `studyforrest dataset`_.

.. image:: /_static/datalad_catalog_demo.svg
   :align: center

|

Index
=====

.. toctree::
   :maxdepth: 1

   overview
   installation
   usage
   pipeline_description
   metadata_formats
   examples
   design
   contributing
   command_line_reference
   python_module_reference
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash

.. _demo catalog: https://datalad.github.io/datalad-catalog/
.. _studyforrest dataset: https://www.studyforrest.org/

